@@ -28,7 +28,7 @@ ResolveNames <- function(names, max.per.call=100, verbose=TRUE) {
         new.names[starting.position + return.index - 
                   1] <- returned.values[[return.index]]$nameScientific
       if (verbose) 
-        print(paste("finished ", name.index, "of ", length(names), "names")) 
+        message(paste("finished ", name.index, "of ", length(names), "names")) 
       starting.position <- name.index + 1
       names.in.call <- 0
       actual.call <- call.base
@@ -38,7 +38,7 @@ ResolveNames <- function(names, max.per.call=100, verbose=TRUE) {
     warning(paste("the input name list was", length(names), 
                   "long but the new one is ", length(new.names), "long"))
   new.names <- sapply(new.names, sub, pattern=" ", replacement="_", USE.NAMES=F)
-  return(print(new.names))
+  return(new.names)
 }
 
 GetPhylotasticToken <- function(names, max.per.call=100, verbose=TRUE) {
@@ -72,12 +72,12 @@ GetPhylotasticToken <- function(names, max.per.call=100, verbose=TRUE) {
         res <- suppressWarnings(fromJSON(postForm(name.call)))
     }
   }
-    print(res$message)
+    cat(res$message, "\n\nOR use the rPlant function RetrieveTNRSNames to pull directly into R")
     return(res$token)
 }
 
 RetrieveTNRSNames <- function(names, token, source=c("iPlant_TNRS", "NCBI"), 
-                              match.threshold=0.5, verbose=F) {
+                              match.threshold=0.5, verbose=FALSE) {
   web <- "http://www.taxosaurus.org/retrieve"
   res <- suppressWarnings(fromJSON(getURL(paste(web, token, sep="/"))))
 
@@ -115,9 +115,9 @@ CompareNames <- function(old.names, new.names, verbose=TRUE) {
     if (comp[i,1] != comp[i,2]) {
       taxa.changed <- taxa.changed + 1
       if (verbose)
-        print(paste(comp[i,1], " was changed to ", comp[i,2], cat("\n")))
+        message(paste0(comp[i,1], " was changed to ", comp[i,2], cat("\n")))
     }
   }
-  print(paste(taxa.changed, "taxa changed names according to TNRS"))
+  return(paste(taxa.changed, "taxa changed names according to TNRS"))
 }
 # -- END --#
